#
# spec file for package courier-imap
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with     valgrind

Name:           courier-imap
Version:        5.2.11
Release:        1.1
Summary:        An IMAP and POP3 Server for Maildir MTAs
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Email/Servers
URL:            https://www.courier-mta.org/imap/
Source0:        https://downloads.sourceforge.net/courier/%{name}-%{version}.tar.bz2
Source1:        https://downloads.sourceforge.net/courier/%{name}-%{version}.tar.bz2.sig
Source2:        pop3.pamd
Source3:        imap.pamd
# Keyring downloaded from https://www.courier-mta.org/KEYS.bin#/%%{name}.keyring
Source4:        %{name}.keyring
Source15:       courier-imap.service
Source16:       courier-imap-ssl.service
Source17:       courier-imap-gencert.service
Source18:       courier-pop.service
Source19:       courier-pop-ssl.service
Source20:       courier-pop-gencert.service
Patch0:         %{name}-sbindir.patch
Patch2:         %{name}-ulimit_conf.patch
### Patch for upstream:
# Apply (open)SUSE specific changes to configuration
Patch4:         %{name}-config.patch
BuildRequires:  audit-libs
BuildRequires:  courier-authlib-devel >= 0.71
BuildRequires:  courier-unicode-devel >= 2.1
BuildRequires:  db-devel
BuildRequires:  gcc-c++
BuildRequires:  gdbm-devel
BuildRequires:  libstdc++-devel
BuildRequires:  ncurses-devel
BuildRequires:  pam-devel
BuildRequires:  pcre2-devel
BuildRequires:  procps
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(libidn2) >= 2.0.5
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(systemd)
%if %{with valgrind}
BuildRequires:  valgrind
%endif
Requires:       courier-authlib >= 0.71
Requires:       gdbm
Requires:       openssl
Conflicts:      cyrus-imapd
Conflicts:      imap
Conflicts:      qpopper
%{?systemd_requires}

%description
Courier-IMAP is a fast, scalable, enterprise IMAP server that uses
Maildirs. Many E-mail service providers use Courier-IMAP to easy handle
hundreds of thousands of mail accounts. With its built-in IMAP and POP3
aggregation proxy, Courier-IMAP has practically infinite horizontal
scalability. In a proxy configuration, a pool of Courier servers service
initial IMAP and POP3 connections from clients. They wait to receive the
client's log in request, look up the server that actually holds this mail
account's mailbox, and establish a proxy connection to the server, all in
a single, seamless process. Mail accounts can be moved between different
servers, to achieve optimum resource usage.

The only practical limitation on Courier-IMAP is available network and I/O
bandwidth. If you are new to Courier-IMAP, this may sound a bit
intimidating. But you do not need to tackle everything at once. Start by
taking small, easy steps. Your first step will be to set up a small
Courier-IMAP server, using it like any other traditional IMAP service, on
a single server. After you gain experience and become comfortable with
Courier, you can then begin exploring its advanced features.

This is the same IMAP server that's included in the Courier mail server,
but configured as a standalone IMAP server that can be used with other
mail servers - such as Qmail, Exim, or Postfix - that deliver to maildirs.
If you already have Courier installed, you do not need to download this
version. If you install this version, you must remove it if you later
install the entire Courier server.

%prep
%autosetup -p0

# For %%doc macro
mv libs/maildir/README.sharedfolders{.txt,}
mv libs/maildir/README.maildirquota{.txt,}

%build
%configure \
	--with-notice=unicode \
	--libexecdir=%{_prefix}/lib/%{name} \
	--datadir=%{_datadir}/%{name} \
	--sysconfdir=%{_sysconfdir}/courier \
	--sharedstatedir=%{_sharedstatedir}/%{name} \
	--with-piddir=%{_rundir} \
	--disable-static \
	--disable-root-check \
	--enable-unicode \
	--with-notice=unicode \
	--with-authdaemonvar=%{_rundir}/courier-authlib \
	--with-certdb=%{_sysconfdir}/ssl/certs \
	--with-certsdir=%{_sysconfdir}/ssl/private \
%if %{without valgrind}
	--enable-workarounds-for-imap-client-bugs
%endif

%make_build

%install
%make_install
# Move daemons into sbin
mv %{buildroot}%{_bindir}/{couriertls,imapd,pop3d} %{buildroot}%{_sbindir}/
# Rename imapd.8 to courier-imapd.8
mv  %{buildroot}%{_mandir}/man8/imapd.8 %{buildroot}%{_mandir}/man8/%{name}d.8
# Install PAM config files
%if 0%{?suse_version} > 1500
mkdir -p %{buildroot}%{_pam_vendordir}
install -D -m 644 %{S:2} %{buildroot}%{_pam_vendordir}/pop3
install -D -m 644 %{S:3} %{buildroot}%{_pam_vendordir}/imap
%else
install -D -m 644 %{S:2} %{buildroot}%{_sysconfdir}/pam.d/pop3
install -D -m 644 %{S:3} %{buildroot}%{_sysconfdir}/pam.d/imap
%endif
# Install init scripts
for i in imap imap-ssl imap-gencert pop pop-ssl pop-gencert; do
  ln -s -f service %{buildroot}%{_sbindir}/rccourier-$i
done
# Install service files
install -d -m 0755 %{buildroot}%{_unitdir}
install -m 0644 %{S:15} %{S:16} %{S:17} %{S:18} %{S:19} %{S:20} %{buildroot}%{_unitdir}
# Remove original init scripts, will not work longer
rm %{buildroot}%{_prefix}/lib/%{name}/imapd.rc
rm %{buildroot}%{_prefix}/lib/%{name}/imapd-ssl.rc
rm %{buildroot}%{_prefix}/lib/%{name}/pop3d.rc
rm %{buildroot}%{_prefix}/lib/%{name}/pop3d-ssl.rc
#
install -D -m 0755 sysconftool %{buildroot}%{_datadir}/%{name}/sysconftool
chmod 755 %{buildroot}%{_datadir}/%{name}/sysconftool
cat >%{buildroot}%{_datadir}/%{name}/configlist <<EOF
%{_sysconfdir}/courier/imapd.dist
%{_sysconfdir}/courier/imapd-ssl.dist
%{_sysconfdir}/courier/pop3d.dist
%{_sysconfdir}/courier/pop3d-ssl.dist
EOF
# SSL state cache directory
install -d %{buildroot}%{_localstatedir}/cache/%{name}/

%if %{with valgrind}
%check
make check
%endif

%pre
%service_add_pre courier-imap-gencert.service courier-imap-ssl.service courier-imap.service
%service_add_pre courier-pop-gencert.service courier-pop-ssl.service courier-pop.service
%if 0%{?suse_version} > 1500
# Prepare for migration to /usr/lib; save any old .rpmsave
for i in pam.d/pop3 pam.d/imap ; do
     test -f %{_sysconfdir}/${i}.rpmsave && mv -v %{_sysconfdir}/${i}.rpmsave %{_sysconfdir}/${i}.rpmsave.old ||:
done
%endif

%preun
%service_del_preun courier-imap-gencert.service courier-imap-ssl.service courier-imap.service
%service_del_preun courier-pop-gencert.service courier-pop-ssl.service courier-pop.service

%post
%{_datadir}/%{name}/sysconftool `cat %{_datadir}/%{name}/configlist` >/dev/null
%service_add_post courier-imap-gencert.service courier-imap-ssl.service courier-imap.service
%service_add_post courier-pop-gencert.service courier-pop-ssl.service courier-pop.service

%postun
%service_del_postun courier-imap-gencert.service courier-imap-ssl.service courier-imap.service
%service_del_postun courier-pop-gencert.service courier-pop-ssl.service courier-pop.service

%if 0%{?suse_version} > 1500
%posttrans
# Migration to /usr/lib, restore just created .rpmsave
for i in pam.d/pop3 pam.d/imap ; do
     test -f %{_sysconfdir}/${i}.rpmsave && mv -v %{_sysconfdir}/${i}.rpmsave %{_sysconfdir}/${i} ||:
done
%endif

%files
%defattr(-,root,root,755)
%license COPYING*
%doc AUTHORS README
%doc libs/imap/ChangeLog libs/imap/BUGS libs/imap/README.proxy
%doc libs/maildir/README.sharedfolders libs/maildir/README.maildirquota
%if 0%{?suse_version} > 1500
%{_pam_vendordir}/imap
%{_pam_vendordir}/pop3
%else
%config %attr(644,root,root) %{_sysconfdir}/pam.d/imap
%config %attr(644,root,root) %{_sysconfdir}/pam.d/pop3
%endif
%dir %{_sysconfdir}/courier
%dir %{_sysconfdir}/courier/imapaccess
%dir %{_sysconfdir}/courier/shared
%dir %{_sysconfdir}/courier/shared.tmp
%config %attr(600,root,root) %{_sysconfdir}/courier/imapd*
%config %attr(600,root,root) %{_sysconfdir}/courier/pop3*
%config %{_sysconfdir}/courier/quotawarnmsg.example
%dir %{_prefix}/lib/%{name}
%{_prefix}/lib/%{name}/makedatprog
%{_prefix}/lib/%{name}/couriertcpd
%dir %{_datadir}/%{name}/
%{_datadir}/%{name}/*
%{_bindir}/*
%{_sbindir}/*
%{_mandir}/man?/*
%{_unitdir}/courier-*.service
%dir %attr(750,root,root) %{_localstatedir}/cache/%{name}/
%ghost %{_localstatedir}/cache/%{name}/sslpop3cache
%ghost %{_localstatedir}/cache/%{name}/sslimapcache

%changelog
* Mon Apr  7 2025 Arjen de Korte <suse+build@de-korte.org>
- update to 5.2.11
  * Fixes several compilation errors from gcc 15.
* Sun Sep  1 2024 Arjen de Korte <suse+build@de-korte.org>
- update to 5.2.10
  * pop3login.c (login_pop3): Fix a problem when proxying UTF8 POP3
    connections.
* Thu Aug  8 2024 Arjen de Korte <suse+build@de-korte.org>
- update to 5.2.9
  * courier-debuild: implement DEBGCC=default, to help with pbuilder.
- update to 5.2.8
  * configure.ac: rpm and deb packaging fixes: remove incorrect MANPATH
    setting, fix warning with newer versions of grep.
* Sat Aug  3 2024 Arjen de Korte <suse+build@de-korte.org>
- update to 5.2.7
  * tcpd: support per-local port custom -haproxy configuration.
    Multiple updates to the couriertcpd man page, updated documentation
    for ipv6 and CIDR support.
  * tcpd: remove -noidentlookup, implement -haproxy
  * couriertcpd: set the IP_FREEBIND option on all listening sockets.
* Sun Nov 26 2023 Arjen de Korte <suse+build@de-korte.org>
- update to 5.2.6
  * Fix generated Date: header issues in timezones that have a
    non-standard alternate timezone offset
  * pop3 and imap logs also indicate whether the connections used
    starttls or stls
  * add missing TLS_PRIVATE_KEYFILE setting to esmtpd.dist
* Wed Aug 30 2023 Arjen de Korte <suse+build@de-korte.org>
- update to 5.2.5
  * Turn off IMAP_TLS_REQUIRED if IMAP_TLS is already set.
  * Compiling with -DMAILDIR_SKIP_SYMLINK_CHECKS turns off checking for
    rogue symlinks in maildirs.
- update courier-imap.keyring with new signing key
* Sun Apr 30 2023 Arjen de Korte <suse+build@de-korte.org>
- update to 5.2.4
  * Fix spurious gcc 13 compiler warnings. Have configure script
    include the standardized location of the CA certificate bundle,
    in addition to various legacy compatibility paths.
* Wed Apr  5 2023 Arjen de Korte <suse+build@de-korte.org>
- update to 5.2.3
  * all: update configure.ac to require at least version 2.0.5 of
    libidn
* Mon Feb 20 2023 Arjen de Korte <suse+build@de-korte.org>
- update to 5.2.2
  * imapd.c (append): No longer accept a non-standard single
    flag name instead of a parenthesized flag list to APPEND, due to
    ambiguity with the UTF8 extension.
* Thu Jan 12 2023 Stefan Schubert <schubi@suse.com>
- Migration of PAM settings to /usr/lib/pam.d.
* Sun Dec 18 2022 Arjen de Korte <suse+build@de-korte.org>
- update to 5.2.1
  * Fix a compatibility problem with OpenSSL 3 that results in TLS
    negotiation failures in some non-default configurations.
  * Fix an error in courier-imap's installation script that results in
    creation of absolute, rather than relative, symbolic links.
* Sun Dec  4 2022 Arjen de Korte <suse+build@de-korte.org>
- update to 5.2.0
  * Switch to libidn2.
  * Debian/Ubuntu: update lintian overrides
  * make install: replace absolute links with relative links.
- update to 5.1.9
  * Adjust deb packaging. Check /etc/lsb-release and include the
    distribution release in the deb package version, to faciliate
    updating to the same version of the package in an updated release.
  * Fix build dependencies.
* Sat Aug 20 2022 Arjen de Korte <suse+build@de-korte.org>
- update to 5.1.8
  * gcc 12 and autotools update. OpenSSL 3.0 update.
  * courier, courier-imap: remove the --disable-root-check configure
    option, now that make check can deal with it.
  * Add scripts to create installable .deb packages, update
    documentation.
  * imap/authenticate_auth.c: Fix broken SASL authentication.
  * Adjust behavior of inherited ACLs. After deleting and recreating
    a folder, have the recreated folder inherit its parent folder's ACLs,
    normally, instead of mysteriously restoring whatever ACLs the folder
    had when it was deleted.
  * Fixes to Makefile to workaround test suite failures related to
    permission checking when make check runs as root.
  * Fix minor memory leaks.
* Mon Jan 17 2022 Arjen de Korte <suse+build@de-korte.org>
- update to 5.1.7
  * Fix linking failure on some Linux distributions.
- update to 5.1.6
  * Fix linking failure on some Linux distributions.
- update to 5.1.5
  * Fix minor memory leaks. If valgrind is installed, "make check" will
    run it to check for memory leaks.
  * Convert to PCRE2.
  * libcouriertls: use ALARM to kill couriertls if the server process
    terminates but openssl hangs trying to shut down the socket.
* Mon Aug  2 2021 Arjen de Korte <suse+build@de-korte.org>
- update to 5.1.4
  * all: code changes so that courier can be compiled with -Wall
  - Werror gcc flags. The default compilation flags are not changed.
    This also includes changes to the configuration scripts, which
    includes removing outdated configuration settings.
  * pop3: buffer input by ourselves, clear input buffer before
    switching to TLS.
  * imap: fix crash if the connection to the client is terminated at
    the wrong/right time.
* Sun Apr 25 2021 Arjen de Korte <suse+build@de-korte.org>
- update to 5.1.3
  * pop3d: pro-forma POP3 LANG extension.
  * pop3d-ssl.dist.in (TLS_STARTTLS_PROTOCOL): Remove duplicate entry
    in the pop3d-ssl configuration file.
* Sat Mar 27 2021 Arjen de Korte <suse+build@de-korte.org>
- update to 5.1.2
  * make: Individual files that did not end in a newline were
    not handled correctly.
  * imap: adjust error message.
* Sun Mar 21 2021 Arjen de Korte <suse+build@de-korte.org>
- update to 5.1.1
  * Fix swapped TLS_CACHEFILE settings in the IMAP and POP3
    configuration files
* Sat Mar 20 2021 Arjen de Korte <suse+build@de-korte.org>
- update to 5.1.0
  * Implement support for the TLS ALPN extension.
  * Replace FAM/Gamin with inotify.
  * Install the maildirwatch tool.
  * Remove the IMAP_ENHANCEDIDLE setting from the imapd configuration
    file.
- update source download URL
- remove courier-imap-Makefile.patch (upstreamed)
* Tue Mar  2 2021 Arjen de Korte <suse+build@de-korte.org>
- update to 5.0.14
  * Fix packaging problem with a faulty courier-unicode dependency
- update to 5.0.13
  * Fixes a crash caused by a malformed DNS query/response
- move SSL cache files to /var/cache/courier-imap/ and put (open)SUSE
  specific changes to configuration files in a patch file (instead of
  sed scripts)
  + courier-imap-config.patch
- remove obsolete SysV init files
  - courier-imap.init
  - courier-imap-ssl.init
  - courier-pop.init
  - courier-pop-ssl.init
* Wed Feb 10 2021 Arjen de Korte <suse+build@de-korte.org>
- update to 5.0.12
  * openssl: Add TLS_PROTOCOL setting to disable client-initiated
    renegotiation.
  * imap: send corrupted Unicode alerts only for new messages.
  * waitlib: fix testwait.c failure with LTO enabled on F33.
  * pop3login.c: fflush before STARTLS.
* Fri Jun 19 2020 Arjen de Korte <suse+build@de-korte.org>
- update to 5.0.11
  * courier-authlib API update.
  * Add AC_PROG_CC_C99 to configure
- remove courier-imap-stdc.patch (no longer needed)
* Thu May 28 2020 Arjen de Korte <suse+build@de-korte.org>
- update to 5.0.10
  * tcpd/starttls.c (dossl): Start client after negotiating SSL, in
    order to allow EXTERNAL client certificate authentication.
  * Fix virtual IP and hostname handling when using GnuTLS for SSL.
  * imap, pop3: include remote port TCP port number together with the
    IP address, in log messages.
- add courier-imap-stdc.patch to remove 'for' loop initial declarations
* Tue Nov 12 2019 Arjen de Korte <suse+build@de-korte.org>
- update to 5.0.8
  * Update documentation in the imapd and pop3d ssl config flies.
- update to 5.0.7
  * pop3dserver.c (do_retr): Use the new MIME_UNICODE_MESSAGE_TYPE
    setting to set the type of the wrapped MIME attachment.
- update to 5.0.6
  * pop3dserver.c: Fix parsing of pop3d file cache, on some
    architectures.
  * tcpd/libcouriertls.c: Ignore unreadable cert files.
- update to 5.0.5
  * fetch.c: Send an alert about a Unicode messages to a non-Unicode
    client at most once per IMAP session.
- update to 5.0.4
  * pop3dserver.c: Deal with MS Outlook's broken implementation of
    RFC 6856.
- update to 5.0.3
  * pop3dserver.c (calcsize): Fix spurious flagging of non-UTF8
    messages as UTF-8.
    To fix existing mailboxes with erroneously-flagged messages. In
    each mailbox, if its existing courierpop3dsizelist file starts with
    /3 [followed by additional data]
    Only if the first line in courierpop3dsizelist starts with /3, then
    execute:
    perl -p -i -e 's/:\d+$/:0/' courierpop3dsizelist
  * pop3dserver.c (readpop3dlist): Be able to update
    courierpop3dsizelist from version 2 to 3 in place.
    (do_retr): Instead of returning an ERR to a non-Unicode client,
    handle Unicode messages by wrapping them as an attachment.
- update to 5.0.2
  * configure.ac: Additional changes to how Unicode messages are
    handled with non-Unicode clients: disclaim all warranties, still
    report an error, but provide the raw message content, as is.
- update to 5.0.1
  * Provide an substitute message to IMAP clients that did not enable
    UTF-8.
  * couriertls: additional fixes.
  * couriertls: option to use a separate file for the SSL certificate's
    private key, as an alternative to the combined keyfile+certificate.
- update to 5.0.0
  * pop3dserver.c: update Courier-IMAP to support UTF8 POP3. Update
    version of the courierpop3dsizelist cache file.
  * courier-imap, sqwebmail: update Courier-IMAP to support UTF8 IMAP.
    Convert maildir folders to use UTF-8 for folder names. Add
  - -checkutf8 and --convutf8 options to maildirmake to convert
    pre-UTF8 maildirs to UTF8 maildirs, a mandatory upgrade procedure.
  * waitlib/configure.ac: Fix typo.
  * libs/tcpd/starttls.c (main): Add -user option. Additional fixes
    to startup script to have couriertls drop root privileges.
  * libs/tcpd/tlsclient.h: add username option, used in couriertls_start
    to set the child process's uid and gid.
  * imaplogin.c (starttls): Set username option for couriertls
  * pop3login.c (starttls): Set username option for couriertls
  * imapd-ssl.dist, pop3d-ssl.dist: Use separate imap and pop3 session
    cache files. Startup script: remove/set ownership and permsission
    on the imap and pop3 session cache files.
  * libs/tcpd/libcouriergnutls.c: Remove usage of deprecated OpenPGP
    API. Tag the "Unexpected SSL connection shutdown" with the "DEBUG"
    label just like the OpenSSL version does.
  * libs/tcpd/starttls.c: If TCPREMOTEIP is set, prepend it to error
    messages.
- delete reproducible.patch (upstreamed)
- add courier-imap.keyring for source verification
- cleanup spec
* Fri Jul 19 2019 matthias.gerstner@suse.com
- removal of SuSEfirewall2 services, since SuSEfirewall2 has been replaced by
  firewalld, see [1].
  [1]: https://lists.opensuse.org/opensuse-factory/2019-01/msg00490.html
* Tue Jun 11 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut the build queues by allowing usage of systemd-mini
* Thu Jan  3 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to override build date (boo#1047218)
* Mon Dec  4 2017 suse+build@de-korte.org
- update to 4.18.2
  * imapd.c (do_folder_delete): Fix check for DELETE INBOX.
  * libs/maildrop/maildir.C (MaildirSave): Fix new/delete mismatch.
  * libs/sqwebmail/gpg.c: Fix external linkage.
  * libs/tcpd/libcouriertls.c: OpenSSL API update.
  * courier-unicode library API update.
  * libs/maildir/maildirquota.c (docheckquota): Skip DT_LNK.
  * OpenSSL 1.1.0 compilation fixes.
  * courier: switch default header encoding to UTF-8.
  * Fix to configure.ac
* Mon Feb 20 2017 kukuk@suse.de
- Don't call insserv if we use systemd
- Don't install LSB init scripts if we use systemd
- Create rc* links to service command if we use systemd
* Fri May 20 2016 kukuk@suse.de
- Remove directories already part of filesystem rpm
* Tue May 17 2016 kukuk@suse.de
- Fix path of SuSEfirewall2.d directory
* Mon May 16 2016 chris@computersalat.de
- update to 4.17.1
  * Fix TLS SNI code.
- update to 4.17.0
  * Stop using SSL2 and SSL3 openssl configuration methods.
  * libs/tcpd/libcouriertls.c: Add support for TLS SNI.
  * imaplogin.c (starttls): flush stdin after negotiating STARTTLS.
  * Fix Courier-IMAP rpm build on pre-systemd systems.
- rebase courier-imap-Makefile.patch
* Wed Aug  5 2015 chris@computersalat.de
- update to 4.16.2
  * imap/mailboxlist.c (match_mailbox_prep): Use strncmp instead of
    memcmp, to pacify overzealous static analysis checkers.
  * Drop SSLv3 from TLS_CIPHER_LIST.
  * imap, pop3: Added AUTH_MKHOMEDIR_SKEL setting.
- update to 4.16.1
  * maildircache.c: fix use after free.
  * mkdhparams: make compatible with libressl
  * Handle 01-Jan-1970 for date-based searches.
  * Update to courier-unicode 1.2.
  * Add the makeimapaccess script.
- add Patch courier-imap-Makefile.patch
* Wed Oct 29 2014 chris@computersalat.de
- update to 4.15.1.20141122
  * tcpd/libcouriertls.c: add parsing options for different protocol
    combination.
  * Update comments in *ssl config files.
  * libs/tcpd/libcouriertls.c (tls_create): Set SSL_OP_NOSSLv3 flag,
    to disable SSL3 support.
  * mkdhparams: TLS_DHPARAMS environmnt variable overrides default
    DH parameter file location.
  * courier-imap.spec.in: generate the default DH parameter file and
    package it into the rpm, instead of generating one on the first
    start.
  * libs/maildir/maildirinfo.c (maildir_info_imapmunge): Fix
    UTF-8 charset name.
  * tcpd/libcouriertls.c (tls_create): Initialize temporary ecdh
    parameters.
  * imap: try to print a message on stderr if the alarm() call, that
    detects FAM library breakage, goes off.
  * mkdhparams: default to 2048 DH params for OpenSSL.
  * courier-imap.service: bump up startup timeout, initial service start
    may take several minutes to generate DH parameters for the first
    time.
- add new dependency
  * courier-unicode-devel (libunicode)
* Thu Sep 25 2014 chris@computersalat.de
- fix courier-imap.service
  * STARTTLS on port 143 (thanks to cschweingruber)
* Sat Mar 15 2014 chris@computersalat.de
- update to 4.15
  * pop3login.c (starttls): Clear input buffer after STARTTLS.
  * imaplogin.c (starttls): Clear input buffer after STARTTLS.
  * Fix various compiler warnings about unchecked results from setuid
    and setgid calls.
  * libs/tcpd/libcouriergnutls.c, libs/tcpd/libcouriertls.c: remove the
    TLS_DHCERTFILE setting, and use TLS_CERTFILE for all functionality.
    Read DH parameters from TLS_CERTFILE, or from the new TLS_DHPARAMS
    environment variable.
  * mkdhparams: New script that generates DH parameters into a standalone
    file.
  * Remove TLS_DHCERTFILE setting from imapd-ssl, pop3d-ssl, esmtpd and
    esmtpd-ssl. Add TLS_DHPARAMS.
  * Update imapd.cnf.openssl, pop3d.cnf.openssl, esmtpd.cnf.openssl,
    set default number of bits for RSA keys to 4096.
  * libs/tcpd/libcouriertls.c (tls_create): Add TLSv1_1_method() and
    TLSv1_2 method(), based on patch by Rob Austein <sra@hactrn.net>.
  * pop3d-ssl.dist.in, imapd-ssl.dist.in: Fix up differences in the
    documentation of TLS options in various config files.
- added systemd service files
- fix build for SLE
  * fam-devel vs gamin-devel
- cleanup spec
  * RPM_BUILD_ROOT -> buildroot
* Wed Jan  8 2014 adrian@suse.de
- use gamin-devel instead of unmaintained fam(-devel) package
* Mon Nov 11 2013 chris@computersalat.de
- update to 4.14.0
  * Autotool chain update.
  * imapd.c (mddelete): Reject DELETE folder if the maildir is a symlink.
  * imapd.c (doId): Implement the IMAP ID EXTENSION.
- 4.13.0
  * imap: add explicit mkdirs on PIDFILE directories to startup scripts.
  * rfc822: workaround for invalid utf-8 input making libidn go off the
    rails.
- fix License
  * GPL-3.0 -> GPL-3.0+
- rebase patches
  * imap-sbindir, imap-ulimit_conf
* Tue Jan 15 2013 chris@computersalat.de
- update to 4.12.0
  * tcpd/libcouriergnutls.c (get_server_cert): Fix size of malloced
    buffer.
  * configure.in: Fix typo in configure check for setvbuf().
- rebase patches
  * sbindir (remove version), ulimit_conf (rename diff -> patch)
* Fri Sep 21 2012 chris@computersalat.de
- update to 4.11.0
  * maildir/maildiraclt.c (maildir_acl_delete): Fix double-free on error
    path of an ENOMEM.
  * courier.spec.in: Fix the RPM spec to work around /bin symlink
    breakage in F17.
  * tcpd/tcpd.c: Update libgnutls API, replace obsoleted functions
    with current API. Obsoletes most TLS_* variables that set protocol
    priorities, replaced with Gnutls-specific single TLS_PRIORITY
    setting (existing TLS_* variables are still used by the OpenSSL
    alternative). Updated *-ssl configuration files accordingly.
  * tcpd: Compilation changes for gnutls 3
  * liblock/mail.c (dotlock_exists): Quell a compiler warning.
  * Miscellaneous spelling fixes.
- rebase sbindir patch (4.8.0 -> 4.11.0)
* Sat Jan  7 2012 chris@computersalat.de
- update to 4.10.0
  * imapd.c (main): Open IMAPDEBUGFILE only if it exists already.
    (do_expunge): Optionally log deletions. Based on a patch by
    William Yodlowsky <wyodlows@andromeda.rutgers.edu>.
  * pop3dserver.c (cleanup): Optionally log deletions. Based on a patch by
    William Yodlowsky <wyodlows@andromeda.rutgers.edu>.
  * imapd.dist.in (IMAP_MOVE_EXPUNGE_TO_TRASH): Officially document how
    IMAPDEBUGFILE works.
  * imapscanclient.c: Postpone Y2038K for a while, for uid validities.
  * liblock/mail.c (dotlock_exists): Handle getting here because of a
    recycled pid.
  * unicode/unicode.c (init_default_chset): Handle NULL from setlocale().
  * rfc2045/reformime.c (main2): Fixed segfault on some arches from an
    initial null given to strtok.
  * rfc2045/reformime.c (main2): On ia64 and arm, argv is in readonly
    memory.
  * pop3dserver.c (openpop3dlist): Try a few times to reopen pop3dsizelist
    if it fails with ESTALE.
  * pop3d.dist.in: Add AUTHSERVICE settings. They've been supported
    all along.
  * Fix gcc 4.6 warnings
  * courier-imap.spec.in: switch to systemd. Remove script used when
    upgrading from ancient pre-sysconftool versions.
  * Fix autoconf warnings.
* Wed Sep 21 2011 chris@computersalat.de
- change --with-authdaemonvar to /var/run/courier-authlib
* Fri May 27 2011 chris@computersalat.de
- update to 4.9.3
  * msgenvelope.c (msgappends): Fix a fatal error upon encountering
    8-bit header content. Heuristically try to interpret it as UTF-8, and
    just ignore invalid UTF-8 sequences.
  - 4.9.2
  * rfc2045/rfc2045cdecode.c: Tolerate lowercase hexadecimal characters
    in quoted-printable-encoded content.
  * unicode/unicode.c: Compilation fixes.
* Sun May  1 2011 chris@computersalat.de
- update to 4.9.1
  * tcpd/libcouriertls.c (tls_create): Remove SSLv2_method().
    (tls_create): Remove "!SSLv2" from the default TLS_CIPHER_LIST.
  * mkimapdcert.in (prefix): Create imapd.pem with 600 perms.
  * mkpop3dcert.in (prefix): Create pop3d.pem with 600 perms.
- for more info please see Changelog file
- fix License
  o GPLv2+ -> GPLv3
- fix path to ChangeLog file
* Mon Oct 11 2010 chris@computersalat.de
- update to 4.8.1
  * Makefile.am (imapd.cnf): Compatibility fixes.
- 2010-08-15  Sam Varshavchik  <mrsam@courier-mta.com>
  * maildir/maildirwatch.c (maildirwatch_alloc): Use alarm() to kill
    the process if FAMOpen() takes more than 15 seconds to return.
    Should prevent a hung process if FAM/Gamin is fubared.
- 2010-07-11  Sam Varshavchik  <mrsam@courier-mta.com>
  * pop3dserver.c: Make printed() and putchar() macros.
- 2010-07-01  Sam Varshavchik  <mrsam@courier-mta.com>
  * imapd.cnf pop3d.cnf (default_md): added default_md = sha1
- 2010-06-28  Sam Varshavchik  <mrsam@courier-mta.com>
  * rfc822/rfc822.c (rfc822_print_common_nameaddr): Prevent segfault if
    address decode fails.
  * Fix make check failure when libidn is not available.
- 2010-05-31  Sam Varshavchik  <mrsam@courier-mta.com>
  * Rebuilt man pages with updated stylesheets.
- remove obsolete certsdir patch
- remove LDFLAGS patch, add configure option --disable-static
* Thu Aug  5 2010 chris@computersalat.de
- have pop3d, imapd ssl certs in /etc/ssl/private
  [bnc#628487]; certsdir patch
* Mon Jul  5 2010 chris@computersalat.de
- update to 4.8.0
  * tcpd/configure.in: Check if explicit linking with libgpg-error is
    required.
- 2010-03-20  "Stefan Hornburg (Racke)" <racke@linuxia.de>
  * imapd.c (main): Fix typo in alert message.
- 2010-03-18  Hugo Monteiro <hugo.monteiro@fct.unl.pt>
  * Big quota patch (with some changes).
- 2010-03-12  Sam Varshavchik  <mrsam@courier-mta.com>
  * imapd.c (main): Dummy FAM/Gamin initialization, report an error
    during login, upon a failure.
- 2010-03-10  Sam Varshavchik  <mrsam@courier-mta.com>
  * imapd.c (imapenhancedidle): Make FAM error more meaningful.
- 2010-02-25  Bernard Quatermass <bernard@quatermass.co.uk>
  * pop3dserver.c (main): "disableinsecurepop3" account option disables
    non-SSL logins.
  * imapd.c (chkdisabled): "disableinsecureimap" account option disables
    non-SSL logins.
- reworked sbindir patch
* Sat Jul  3 2010 meissner@suse.de
- buildrequire openssl so configure finds /usr/bin/openssl bnc#619665
* Mon May 17 2010 chris@computersalat.de
- fix path to TLS_TRUSTCERTS (imap-ssl,pop3d-ssl)
  o added --with-certdb=%%{_sysconfdir}/ssl/certs
* Wed Feb 24 2010 chris@computersalat.de
- update to 4.7.0
  * lot of changes, see ChangeLog
- reworked LDFLAGS patch (fuzz 0)
* Tue Oct  6 2009 chris@computersalat.de
- update to 4.6.0
  * outbox.c (imapd_sendmsg): Renamed sendmsg() to avoid library name
    clash.
  * tls: change the default OpenSSL configuration to disable anonymous
    authentication ciphers
* Sat Sep  5 2009 chris@computersalat.de
- spec mods
  o resorted Tags
* Sat Sep  5 2009 chris@computersalat.de
- update to 4.5.1
  * all: gcc 4.4 fixes
  * fetch.c (open_cached_fp): If the message file cannot be opened,
    create a dummy message in its place.
- spec mods
  o added missing norootforbuild
  o fix patch naming patch0
- mod to imapd.dist
  o increased MAXPERIP from 10 to 20
    thunderbird does 5 con per account, if not known by user
    he will come into trouble
* Wed Aug 26 2009 chris@computersalat.de
- spec mods
  o fix typo missing '%%'if
* Thu Aug 20 2009 chris@computersalat.de
- cleanup spec file
  o removed all #---- lines
  o added configure macro
- merge .spec with o:F
- merge .changes with o:F
* Thu Aug 20 2009 opensuse@cboltz.de
- read ssl config files in non-ssl initscripts if TLS is enabled
  [bnc#420972#c2]
* Tue Jul  7 2009 chris@computersalat.de
- fixed self prov error (imap)
* Sun May 24 2009 chris@computersalat.de
- new version 4.5.0
  o Documentation refresh.
  o pop3dserver.c: s/POP3_STLS/POP3_TLS/, for correct logging.
  o imaprefs.c (dorefcreate): Clean up usage of rfc822_threadsearchmsg().
    A malloc() failure wasn't checked correctly.
  o rfc2045/rfc2045_fromfd.c: Optimize header parsing.
  o search.c: Empty MIME entities would always match any SEARCH. Reported
    by Dmitry Osipov.
  o tcpd/configure.in: --without-gnutls forces suppression of GnuTLS when
    OpenSSL is not present.
  o tcpd/libcouriergnutls.c (tls_connect): Fix client certificate request
    settings.
  o tcpd/libcouriergnutls.c (set_cert): Add support for certificates
    signed by an intermediate CA.
  o imapwrite.c (write_error_exit): Dump fatal errors to stderr.
- new sbindir (failed), LDFLAGS (hunk) patch
- some spec fixes
  o updated header
  o updated description
  o added ChangeLog, README.proxy
  o fixed init install (0755)
  o conflicts with cyrus-imapd
- fixed init scripts
  o removed X-United stuff
- rpmlint stuff
  o install-no-mkdir-buildroot
  o removed old Obsoletes
  o fixed non-conffile-in-etc
* Sat May 23 2009 chris@computersalat.de
- fixed differences of changelog
  o my fault, added changes to spec, now fixed :)
* Sat Nov 15 2008 chris@computersalat.de
- some rpmlint stuff
  o modified post: insserv courier-*
* Tue Sep 16 2008 hvogel@suse.de
- Fix init scripts without ssl to not include ssl config files
  [bnc#420972]
* Fri Sep 12 2008 hvogel@suse.de
- Fix protocol names in firewall service files [bnc#425216]
* Mon Sep  8 2008 hvogel@suse.de
- update to 4.4.1
  * Update descriptions of maildir quotas
  * Use the couriertls library to invoke couriertls. SASL
    authentication did not correctly handle the special case of "="
    passed as the initial response to indicate an empty initial
    response. Switch to the new auth_sasl_ex() API.
  * Check the environment variables for subject fields set by
    couriertls. Advertise the AUTH EXTERNAL capability, if they
    are set.
  * Optimize IMAP keyword implementation. Faster results in exchange
    for a concurrency tradeoff if two concurrent sessions attempt to
    update keywords for the same message at the same time
  * Backslashed special characters in address names weren't being
    dequoted correctly
  * Add a timeout to the POP3 login stage
  * Fix SSL initialization
  * Fix TLS session caching
* Mon Apr 14 2008 aj@suse.de
- Remove executable permissions from README files.
* Wed Apr  2 2008 hvogel@suse.de
- update to version 4.3.1
  * make SSL23 default tls protocol
  * update description of SSL/TLS-related settings
  * introduce IMAP_MAILBOX_SANITY_CHECK
  * Explicitly make stderr line-buffered
  * Suppress spurious error message in imap.c
- fix some rpmlint warnings
* Thu Jan 17 2008 mskibbe@suse.de
- update to version 4.3.0 which
  o Fix some Bugs
  o Fix SSL session caching bug
  o Make skew check more reliable
  o code cleanup
* Wed Nov 21 2007 mskibbe@suse.de
- Bug 342601 - courier-imap rc and config bugs
* Fri Nov 16 2007 mskibbe@suse.de
- Bug 341267 - courier-imap-ssl configuration problems
* Mon Oct 22 2007 sbrabec@suse.cz
- Use correct SuSEfirewall2 rule directory.
* Wed Apr 25 2007 mskibbe@suse.de
- update to version 4.1.3 which includes:
  o fix memory leak
  o checks for malloc failures
  o updated man pages
  o cleaned up configure script
  o bug fixes
* Mon Apr 23 2007 mskibbe@suse.de
- SuSEfirewall2 service file installed in wrong dir/broken
  (#266949)
* Thu Mar 29 2007 rguenther@suse.de
- add procps BuildRequries because of interesting configure checks
* Mon Mar 26 2007 rguenther@suse.de
- add gdbm-devel BuildRequires
* Wed Mar 14 2007 mskibbe@suse.de
- fam has no address, rejected by xinetd, when called from
  courier-imap (#253437)
* Fri Mar  2 2007 mskibbe@suse.de
- courier : Support for FATE #300687: Ports for SuSEfirewall added
  via packages (#250575)
- fix file list
- update to version 2.1.2 which
  o Clarify some error messages
  o Try to log bandwidth usage before getting killed by a signal
  o Fix many compiler warnings
  o Fix segfault if non-cert files were found in the cert dir
  o Added koi8-u character set
* Mon Feb 12 2007 mskibbe@suse.de
- fix mkpop3dcert and mkimapdcert. Now they use pem files from
  /etc/courier-imap/
* Mon Feb  5 2007 mskibbe@suse.de
- Courier generates certificates in /usr/share/courier-imap
  (#241937)
* Mon Jan 22 2007 mskibbe@suse.de
- checkproc uses -p parameter not as specified in man page
  (#230806)
* Mon Sep 11 2006 tpatzig@suse.de
- Add Conflict to qpopper
* Tue Aug  1 2006 mskibbe@suse.de
- update to version 4.1.1 which
  o fixed some compiler warnings
  o fix segfault if non-cert files were found in the cert dir
  o Added koi8-u character set
  o fix quota calculations on 32 bit platforms with 64 bit off_t
  o Don't assume that connect() of a non-blocking socket always
    fails with INPROGRESS
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Dec  6 2005 kukuk@suse.de
- Don't link static
* Mon Nov 14 2005 kukuk@suse.de
- Add postfix to nfb to fix location of sendmail [#133327]
* Wed Nov  2 2005 kukuk@suse.de
-  Update to version 4.0.6
* Fri Sep 23 2005 kukuk@suse.de
- Fix imapd and pop3d init scripte for SSL connections [#113213]
* Mon Sep 19 2005 kukuk@suse.de
- Update to version 4.0.5
* Fri Aug 26 2005 kukuk@suse.de
- Rename courier-pop3* init scripts to courier-pop* to be
  LSB conform
- Source imapd-ssl and pop3-ssl from init scripts [#113213],
  use correct SSLPIDFILE variable and add path to checkproc
* Wed Aug  3 2005 kukuk@suse.de
- Update to version 4.0.4
* Thu Jul 21 2005 kukuk@suse.de
- Use Maildir from config file [#94231]
- If user removed PIDFILE entry from config file, set default
  one [#85845]
* Thu Nov 18 2004 kukuk@suse.de
- Update to release 3.0.8
* Mon Nov 15 2004 kukuk@suse.de
- Use common-* PAM config files for imap and pop3
* Mon Sep  6 2004 kukuk@suse.de
- Fix permission of /usr/lib/courier-imap/authlib/authdaemond.ldap
  [#44721]
* Mon Aug 16 2004 kukuk@suse.de
- Update to bug fix release 3.0.7
* Wed May 12 2004 kukuk@suse.de
- Update to 3.0.3
* Thu Mar 25 2004 mmj@suse.de
- Add postfix to # neededforbuild
* Wed Mar 17 2004 kukuk@suse.de
- Update to 3.0.2: vpopmail password fixes, filesystem/ACL fixes
* Mon Mar  8 2004 kukuk@suse.de
- Update to official 3.0.0 release
* Mon Feb  9 2004 kukuk@suse.de
- Update to official 2.2.1 release
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Fri Aug 29 2003 kukuk@suse.de
- Add conflict with imap package
* Tue Aug 26 2003 kukuk@suse.de
- Fix typo in spec file
- Update to 2.1.1
* Sun Aug  3 2003 aj@suse.de
- Package sysconftool also.
* Fri Aug  1 2003 kukuk@suse.de
- Rename imapd.8 to courier-imapd.8 to resolve file conflicts.
* Wed Jul 30 2003 kukuk@suse.de
- Initial version
